@@ -46,8 +46,7 @@ func (e *eventWatchInterval) Prompt() string {
 // Confirm returns the event when the input is confirmed.
 func (e *eventWatchInterval) Confirm(str string) tcell.Event {
 	e.value = str
-	e.clist.list = toLast(e.clist.list, str)
-	e.clist.p = 0
+	e.clist.toLast(str)
 	e.SetEventNow()
 	return e
 }
