@@ -17,7 +17,7 @@ func baCandidate() *candidate {
 	}
 }
 
-// eventWriteBA represents the WatchInteval input mode.
+// eventWriteBA represents the writeBA input mode.
 type eventWriteBA struct {
 	tcell.EventTime
 	clist *candidate
@@ -42,8 +42,7 @@ func (e *eventWriteBA) Prompt() string {
 // Confirm returns the event when the input is confirmed.
 func (e *eventWriteBA) Confirm(str string) tcell.Event {
 	e.value = str
-	e.clist.list = toLast(e.clist.list, str)
-	e.clist.p = 0
+	e.clist.toLast(str)
 	e.SetEventNow()
 	return e
 }
