@@ -4,7 +4,6 @@ import (
 	"regexp"
 	"strings"
 
-	"github.com/mattn/go-runewidth"
 	"golang.org/x/exp/constraints"
 )
 
@@ -91,7 +90,7 @@ func allStringIndex(s string, substr string) [][]int {
 		return nil
 	}
 	var result [][]int
-	width := wordWidth(substr)
+	width := len(substr)
 	for pos, offSet := strings.Index(s, substr), 0; pos != -1; {
 		s = s[pos+width:]
 		result = append(result, []int{pos + offSet, pos + offSet + width})
@@ -100,16 +99,3 @@ func allStringIndex(s string, substr string) [][]int {
 	}
 	return result
 }
-
-// wordWidth returns the width of the word.
-func wordWidth(str string) int {
-	width := 0
-	for _, r := range str {
-		w := runewidth.RuneWidth(r)
-		if w == 0 {
-			w = 1
-		}
-		width += w
-	}
-	return width
-}
